@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *   Copyright 2010 Johannes Löhnert <loehnert.kde@gmx.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+    SPDX-FileCopyrightText: 2010 Johannes Löhnert <loehnert.kde@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "piece.h"
 #include "piece_p.h"
@@ -46,11 +34,11 @@ void Palapeli::Piece::commonInit(const Palapeli::PieceVisuals& pieceVisuals)
 }
 
 Palapeli::Piece::Piece(const QImage& pieceImage, const QPoint& offset)
-	: m_pieceItem(0)
-	, m_inactiveShadowItem(0)
-	, m_activeShadowItem(0)
-	, m_highlightItem(0)
-	, m_animator(0)
+	: m_pieceItem(nullptr)
+	, m_inactiveShadowItem(nullptr)
+	, m_activeShadowItem(nullptr)
+	, m_highlightItem(nullptr)
+	, m_animator(nullptr)
 	, m_offset(offset)
 {
 	//create bevel map if wanted
@@ -69,11 +57,11 @@ Palapeli::Piece::Piece(const QImage& pieceImage, const QPoint& offset)
 }
 
 Palapeli::Piece::Piece(const Palapeli::PieceVisuals& pieceVisuals, const Palapeli::PieceVisuals& shadowVisuals, const Palapeli::PieceVisuals& highlightVisuals)
-	: m_pieceItem(0)
-	, m_inactiveShadowItem(0)
-	, m_activeShadowItem(0)
-	, m_highlightItem(0)
-	, m_animator(0)
+	: m_pieceItem(nullptr)
+	, m_inactiveShadowItem(nullptr)
+	, m_activeShadowItem(nullptr)
+	, m_highlightItem(nullptr)
+	, m_animator(nullptr)
 	, m_offset(QPoint(0, 0))	// Gets set in Piece::commonInit().
 {
 	commonInit(pieceVisuals);
@@ -236,7 +224,7 @@ void Palapeli::Piece::pieceItemSelectedChanged(bool selected)
 
 void Palapeli::Piece::addRepresentedAtomicPieces(const QList<int>& representedAtomicPieces)
 {
-	foreach (int id, representedAtomicPieces)
+	for (int id : representedAtomicPieces)
 		if (!m_representedAtomicPieces.contains(id))
 			m_representedAtomicPieces << id;
 }
@@ -248,7 +236,7 @@ QList<int> Palapeli::Piece::representedAtomicPieces() const
 
 void Palapeli::Piece::addLogicalNeighbors(const QList<Palapeli::Piece*>& logicalNeighbors)
 {
-	foreach (Palapeli::Piece* piece, logicalNeighbors)
+	for (Palapeli::Piece* piece : logicalNeighbors)
 		// IDW TODO - if (!m_logicalNeighbors.contains(piece) && piece)
 		//            If piece == 0, pieceID was not in m_loadedPieces.
 		//            This would be an integrity error in .puzzle file.
@@ -264,7 +252,7 @@ QList<Palapeli::Piece*> Palapeli::Piece::logicalNeighbors() const
 void Palapeli::Piece::rewriteLogicalNeighbors(const QList<Palapeli::Piece*>& oldPieces, Palapeli::Piece* newPiece)
 {
 	bool oldPiecesFound = false;
-	foreach (Palapeli::Piece* oldPiece, oldPieces)
+	for (Palapeli::Piece* oldPiece : oldPieces)
 	{
 		int index = m_logicalNeighbors.indexOf(oldPiece);
 		if (index != -1)
@@ -279,7 +267,7 @@ void Palapeli::Piece::rewriteLogicalNeighbors(const QList<Palapeli::Piece*>& old
 
 void Palapeli::Piece::announceReplaced(Palapeli::Piece* replacement)
 {
-	emit replacedBy(replacement);
+	Q_EMIT replacedBy(replacement);
 	deleteLater();
 }
 
@@ -359,14 +347,14 @@ void Palapeli::Piece::doMove()
 	Palapeli::Scene* scene = qobject_cast<Palapeli::Scene*>(this->scene());
 	if (scene) {
 		scene->validatePiecePosition(this);
-		emit moved(false);	// Still moving.
+		Q_EMIT moved(false);	// Still moving.
 	}
 }
 
 void Palapeli::Piece::endMove()
 {
 	m_pieceItem->setCursor(Qt::OpenHandCursor);
-	emit moved(true);		// Finishd moving.
+	Q_EMIT moved(true);		// Finishd moving.
 }
 
 //END mouse interaction
